@@ -44,7 +44,7 @@ var searchData=
   ['graphicmapper_2eidl_41',['GraphicMapper.idl',['../GraphicMapper_8idl.html',1,'']]],
   ['graphicobject_2eidl_42',['GraphicObject.idl',['../GraphicObject_8idl.html',1,'']]],
   ['graphicobjectcount_2eidl_43',['GraphicObjectCount.idl',['../GraphicObjectCount_8idl.html',1,'']]],
-  ['graphicobjectshape_2eidl_44',['GraphicObjectShape.idl',['../drawing_2GraphicObjectShape_8idl.html',1,'(Global Namespace)'],['../presentation_2GraphicObjectShape_8idl.html',1,'(Global Namespace)']]],
+  ['graphicobjectshape_2eidl_44',['graphicobjectshape.idl',['../presentation_2GraphicObjectShape_8idl.html',1,'(Global Namespace)'],['../drawing_2GraphicObjectShape_8idl.html',1,'(Global Namespace)']]],
   ['graphicprovider_2eidl_45',['GraphicProvider.idl',['../GraphicProvider_8idl.html',1,'']]],
   ['graphicrasterizer_2eidl_46',['GraphicRasterizer.idl',['../GraphicRasterizer_8idl.html',1,'']]],
   ['graphicrenderervcl_2eidl_47',['GraphicRendererVCL.idl',['../GraphicRendererVCL_8idl.html',1,'']]],
@@ -52,15 +52,15 @@ var searchData=
   ['graphictype_2eidl_49',['GraphicType.idl',['../GraphicType_8idl.html',1,'']]],
   ['gridcolumn_2eidl_50',['GridColumn.idl',['../GridColumn_8idl.html',1,'']]],
   ['gridcolumnevent_2eidl_51',['GridColumnEvent.idl',['../GridColumnEvent_8idl.html',1,'']]],
-  ['gridcontrol_2eidl_52',['GridControl.idl',['../control_2GridControl_8idl.html',1,'(Global Namespace)'],['../component_2GridControl_8idl.html',1,'(Global Namespace)']]],
+  ['gridcontrol_2eidl_52',['gridcontrol.idl',['../control_2GridControl_8idl.html',1,'(Global Namespace)'],['../component_2GridControl_8idl.html',1,'(Global Namespace)']]],
   ['griddataevent_2eidl_53',['GridDataEvent.idl',['../GridDataEvent_8idl.html',1,'']]],
   ['gridinvaliddataexception_2eidl_54',['GridInvalidDataException.idl',['../GridInvalidDataException_8idl.html',1,'']]],
   ['gridinvalidmodelexception_2eidl_55',['GridInvalidModelException.idl',['../GridInvalidModelException_8idl.html',1,'']]],
   ['gridproperties_2eidl_56',['GridProperties.idl',['../GridProperties_8idl.html',1,'']]],
   ['gridselectionevent_2eidl_57',['GridSelectionEvent.idl',['../GridSelectionEvent_8idl.html',1,'']]],
-  ['group_2eidl_58',['Group.idl',['../sdbcx_2Group_8idl.html',1,'(Global Namespace)'],['../report_2Group_8idl.html',1,'(Global Namespace)']]],
+  ['group_2eidl_58',['group.idl',['../report_2Group_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Group_8idl.html',1,'(Global Namespace)']]],
   ['groupaccess_2eidl_59',['GroupAccess.idl',['../GroupAccess_8idl.html',1,'']]],
-  ['groupbox_2eidl_60',['GroupBox.idl',['../component_2GroupBox_8idl.html',1,'(Global Namespace)'],['../control_2GroupBox_8idl.html',1,'(Global Namespace)']]],
+  ['groupbox_2eidl_60',['groupbox.idl',['../component_2GroupBox_8idl.html',1,'(Global Namespace)'],['../control_2GroupBox_8idl.html',1,'(Global Namespace)']]],
   ['groupdescriptor_2eidl_61',['GroupDescriptor.idl',['../GroupDescriptor_8idl.html',1,'']]],
   ['groupelement_2eidl_62',['GroupElement.idl',['../GroupElement_8idl.html',1,'']]],
   ['groupkeeptogether_2eidl_63',['GroupKeepTogether.idl',['../GroupKeepTogether_8idl.html',1,'']]],
